@@ -1,13 +1,15 @@
 package App::bif::list::identities;
 use strict;
 use warnings;
-use parent 'App::bif::Context';
+use Bif::Mo;
 use Term::ANSIColor 'color';
 
-our $VERSION = '0.1.0_28';
+our $VERSION = '0.1.2';
+extends 'App::bif';
 
 sub run {
-    my $self  = __PACKAGE__->new(shift);
+    my $self  = shift;
+    my $opts  = $self->opts;
     my $db    = $self->db;
     my $dark  = color('dark');
     my $reset = color('reset');
@@ -44,8 +46,6 @@ sub run {
     print $self->render_table( ' l r  l  l l ',
         [ 'Type', 'ID', 'Name', 'Contact (Method)', '' ], $data );
 
-    $self->end_pager;
-
     return $self->ok('ListIdentities');
 }
 
@@ -54,11 +54,13 @@ __END__
 
 =head1 NAME
 
+=for bif-doc #retrieve
+
 bif-list-identities - list identities present in repository
 
 =head1 VERSION
 
-0.1.0_28 (2014-09-23)
+0.1.2 (2014-10-08)
 
 =head1 SYNOPSIS
 
@@ -66,7 +68,7 @@ bif-list-identities - list identities present in repository
 
 =head1 DESCRIPTION
 
-The C<bif list identities> command lists the identities present in the
+The B<bif-list-identities> command lists the identities present in the
 current repository.
 
 =head1 SEE ALSO
