@@ -1,13 +1,15 @@
 package App::bif::list::plans;
 use strict;
 use warnings;
-use parent 'App::bif::Context';
+use Bif::Mo;
 use Term::ANSIColor 'color';
 
-our $VERSION = '0.1.0_28';
+our $VERSION = '0.1.2';
+extends 'App::bif';
 
 sub run {
-    my $self  = __PACKAGE__->new(shift);
+    my $self  = shift;
+    my $opts  = $self->opts;
     my $db    = $self->db;
     my $dark  = color('dark');
     my $reset = color('reset');
@@ -37,8 +39,6 @@ sub run {
     print $self->render_table( ' l r  l  l  l ',
         [ 'Type', 'ID', 'Name', 'Title', 'Provider' ], $data );
 
-    $self->end_pager;
-
     return $self->ok('ListPlans');
 }
 
@@ -47,24 +47,26 @@ __END__
 
 =head1 NAME
 
-bifhub-list-plans - list plans present in repository
+=for bif-doc #hubadmin
+
+bif-list-plans - list plans present in repository
 
 =head1 VERSION
 
-0.1.0_28 (2014-09-23)
+0.1.2 (2014-10-08)
 
 =head1 SYNOPSIS
 
-    bifhub list plans
+    bif list plans
 
 =head1 DESCRIPTION
 
-The C<bifhub list plans> command lists the provider plans present in
-the current repository.
+The B<bif-list-plans> command lists the provider plans present in the
+current repository.
 
 =head1 SEE ALSO
 
-L<bifhub>(1)
+L<bif>(1)
 
 =head1 AUTHOR
 
