@@ -2,14 +2,16 @@ package App::bif::log::issue;
 use strict;
 use warnings;
 use feature 'state';
-use parent 'App::bif::log';
+use Bif::Mo;
 
-our $VERSION = '0.1.0_28';
+our $VERSION = '0.1.2';
+extends 'App::bif::log';
 
 sub run {
-    my $self = __PACKAGE__->new(shift);
+    my $self = shift;
+    my $opts = $self->opts;
     my $db   = $self->db;
-    my $info = $self->get_topic( $self->{id}, 'issue' );
+    my $info = $self->get_topic( $opts->{id}, 'issue' );
 
     state $have_dbix = DBIx::ThinSQL->import(qw/ qv concat /);
 
@@ -59,11 +61,9 @@ sub run {
     $sth->execute;
     $self->start_pager;
 
-    $self->init;
     $self->log_item( $sth->hashref, 'issue' );
     $self->log_comment($_) for $sth->hashrefs;
 
-    $self->end_pager;
     return $self->ok('LogIssue');
 }
 
@@ -72,11 +72,13 @@ __END__
 
 =head1 NAME
 
+=for bif-doc #history
+
 bif-log-issue - review the history of a issue
 
 =head1 VERSION
 
-0.1.0_28 (2014-09-23)
+0.1.2 (2014-10-08)
 
 =head1 SYNOPSIS
 
@@ -84,7 +86,7 @@ bif-log-issue - review the history of a issue
 
 =head1 DESCRIPTION
 
-The C<bif log issue> command displays the history of an issue.
+The B<bif-log-issue> command displays the history of an issue.
 
 =head1 ARGUMENTS & OPTIONS
 
