@@ -2,14 +2,16 @@ package App::bif::log::project;
 use strict;
 use warnings;
 use feature 'state';
-use parent 'App::bif::log';
+use Bif::Mo;
 
-our $VERSION = '0.1.0_28';
+our $VERSION = '0.1.2';
+extends 'App::bif::log';
 
 sub run {
-    my $self = __PACKAGE__->new(shift);
+    my $self = shift;
+    my $opts = $self->opts;
     my $db   = $self->db;
-    my $info = $self->get_project( $self->{path} );
+    my $info = $self->get_project( $opts->{path} );
 
     state $have_dbix = DBIx::ThinSQL->import(qw/ qv concat /);
 
@@ -58,12 +60,10 @@ sub run {
 
     $self->start_pager;
 
-    $self->init;
     my $first = $sth->hashref;
     $self->log_item( $first, 'project', [ 'Phase', $first->{status} ] );
     $self->log_comment($_) for $sth->hashrefs;
 
-    $self->end_pager;
     return $self->ok('LogProject');
 }
 
@@ -72,11 +72,13 @@ __END__
 
 =head1 NAME
 
+=for bif-doc #history
+
 bif-log-project - review a project history
 
 =head1 VERSION
 
-0.1.0_28 (2014-09-23)
+0.1.2 (2014-10-08)
 
 =head1 SYNOPSIS
 
@@ -84,7 +86,7 @@ bif-log-project - review a project history
 
 =head1 DESCRIPTION
 
-The C<bif log project> command displays a project history.
+The B<bif-log-project> command displays a project history.
 
 =head1 ARGUMENTS & OPTIONS
 
