@@ -1,24 +1,26 @@
 package App::bif::new::host;
 use strict;
 use warnings;
-use parent 'App::bif::Context';
+use Bif::Mo;
 use DBIx::ThinSQL qw/bv/;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.0_28';
+our $VERSION = '0.1.2';
+extends 'App::bif';
 
 sub run {
-    my $self = __PACKAGE__->new(shift);
-    my $db   = $self->dbw;
+    my $self = shift;
+    my $opts = $self->opts;
+    my $dbw  = $self->dbw;
 
-    $self->{name} ||= prompt( 'Name:', '' )
+    $opts->{name} ||= prompt( 'Name:', '' )
       || return $self->err( 'NameRequired', 'name is required' );
 
-    $self->{message} ||= "New host $self->{name}";
+    $opts->{message} ||= "New host $opts->{name}";
 
     my $provider;
-    if ( $self->{name} =~ s/(.*?):(.*)/$2/ ) {
-        $provider = $db->xhashref(
+    if ( $opts->{name} =~ s/(.*?):(.*)/$2/ ) {
+        $provider = $dbw->xhashref(
             select     => [qw/p.id e.name/],
             from       => 'providers p',
             inner_join => 'entities e',
@@ -30,7 +32,7 @@ sub run {
           unless $provider;
     }
     else {
-        my @providers = $db->xhashrefs(
+        my @providers = $dbw->xhashrefs(
             select     => [qw/p.id e.name/],
             from       => 'providers p',
             inner_join => 'entities e',
@@ -46,13 +48,13 @@ sub run {
         $provider = $providers[0];
     }
 
-    $db->txn(
+    $dbw->txn(
         sub {
-            my $uid = $self->new_change( message => $self->{message}, );
+            my $uid = $self->new_change( message => $opts->{message}, );
 
-            my $id = $db->nextval('topics');
+            my $id = $dbw->nextval('topics');
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_new_topic',
                 values      => {
                     id        => $id,
@@ -61,36 +63,36 @@ sub run {
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_new_host',
                 values      => {
                     id          => $id,
                     change_id   => $uid,
                     provider_id => $provider->{id},
-                    name        => $self->{name},
+                    name        => $opts->{name},
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'change_deltas',
                 values      => {
                     change_id         => $uid,
                     new               => 1,
-                    action_format     => "new host (%s) $self->{name}",
+                    action_format     => "new host (%s) $opts->{name}",
                     action_topic_id_1 => $id,
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_merge_changes',
                 values      => { merge => 1 },
             );
 
-            printf( "Host created: %s:%s\n", $provider->{name}, $self->{name} );
+            printf( "Host created: %s:%s\n", $provider->{name}, $opts->{name} );
 
             # For test scripts
-            $self->{id}        = $id;
-            $self->{change_id} = $uid;
+            $opts->{id}        = $id;
+            $opts->{change_id} = $uid;
         }
     );
 
@@ -102,19 +104,21 @@ __END__
 
 =head1 NAME
 
-bifhub-new-host - create a new host in the repository
+=for bif-doc #hubadmin
+
+bif-new-host - create a new host in the repository
 
 =head1 VERSION
 
-0.1.0_28 (2014-09-23)
+0.1.2 (2014-10-08)
 
 =head1 SYNOPSIS
 
-    bifhub new host [NAME]
+    bif new host [NAME]
 
 =head1 DESCRIPTION
 
-The C<bifhub new host> command creates a new host of bif hub hosting.
+The B<bif-new-host> command creates a new host of bif hub hosting.
 
 =head1 ARGUMENTS & OPTIONS
 
@@ -134,7 +138,7 @@ The creation message, set to "" by default.
 
 =head1 SEE ALSO
 
-L<bifhub>(1)
+L<bif>(1)
 
 =head1 AUTHOR
 
