@@ -1,34 +1,36 @@
 package App::bif::new::provider;
 use strict;
 use warnings;
-use parent 'App::bif::Context';
+use Bif::Mo;
 use DBIx::ThinSQL qw/bv/;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.0_28';
+our $VERSION = '0.1.2';
+extends 'App::bif';
 
 sub run {
-    my $self = __PACKAGE__->new(shift);
-    my $db   = $self->dbw;
+    my $self = shift;
+    my $opts = $self->opts;
+    my $dbw  = $self->dbw;
 
-    $self->{name} ||= prompt( 'Name:', '' )
+    $opts->{name} ||= prompt( 'Name:', '' )
       || return $self->err( 'NameRequired', 'name is required' );
 
-    $self->{method} ||= prompt( 'Contact Method:', 'email' )
+    $opts->{method} ||= prompt( 'Contact Method:', 'email' )
       || return $self->err( 'MethodRequired', 'method is required' );
 
-    $self->{value} ||= prompt( 'Contact Value:', '' )
+    $opts->{value} ||= prompt( 'Contact Value:', '' )
       || return $self->err( 'ValueRequired', 'value is required' );
 
-    $self->{message} ||= "New provider $self->{name}";
+    $opts->{message} ||= "New provider $opts->{name}";
 
-    $db->txn(
+    $dbw->txn(
         sub {
-            my $id    = $db->nextval('topics');
-            my $ecmid = $db->nextval('topics');
-            my $uid   = $self->new_change( message => $self->{message}, );
+            my $id    = $dbw->nextval('topics');
+            my $ecmid = $dbw->nextval('topics');
+            my $uid   = $self->new_change( message => $opts->{message}, );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_new_topic',
                 values      => {
                     id        => $id,
@@ -37,16 +39,16 @@ sub run {
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_new_entity',
                 values      => {
                     id        => $id,
                     change_id => $uid,
-                    name      => $self->{name},
+                    name      => $opts->{name},
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_new_topic',
                 values      => {
                     id        => $ecmid,
@@ -55,19 +57,19 @@ sub run {
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_new_entity_contact_method',
                 values      => {
                     change_id => $uid,
                     id        => $ecmid,
                     entity_id => $id,
-                    method    => $self->{method},
-                    mvalue    => bv( $self->{value}, DBI::SQL_VARCHAR ),
+                    method    => $opts->{method},
+                    mvalue    => bv( $opts->{value}, DBI::SQL_VARCHAR ),
                 },
             );
 
-            $db->xdo(
-                insert_into => 'func_change_entity',
+            $dbw->xdo(
+                insert_into => 'func_update_entity',
                 values      => {
                     change_id                 => $uid,
                     id                        => $id,
@@ -76,7 +78,7 @@ sub run {
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_new_provider',
                 values      => {
                     id        => $id,
@@ -84,17 +86,17 @@ sub run {
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'change_deltas',
                 values      => {
                     change_id         => $uid,
                     new               => 1,
-                    action_format     => "new provider (%s) $self->{name}",
+                    action_format     => "new provider (%s) $opts->{name}",
                     action_topic_id_1 => $id,
                 },
             );
 
-            $db->xdo(
+            $dbw->xdo(
                 insert_into => 'func_merge_changes',
                 values      => { merge => 1 },
             );
@@ -102,8 +104,8 @@ sub run {
             printf( "Provider created: %d\n", $id );
 
             # For test scripts
-            $self->{id}        = $id;
-            $self->{change_id} = $uid;
+            $opts->{id}        = $id;
+            $opts->{change_id} = $uid;
         }
     );
 
@@ -115,19 +117,21 @@ __END__
 
 =head1 NAME
 
-bifhub-new-provider - create a new provider in the repository
+=for bif-doc #hubadmin
+
+bif-new-provider - create a new provider in the repository
 
 =head1 VERSION
 
-0.1.0_28 (2014-09-23)
+0.1.2 (2014-10-08)
 
 =head1 SYNOPSIS
 
-    bifhub new provider [NAME] [METHOD] [VALUE] [OPTIONS...]
+    bif new provider [NAME] [METHOD] [VALUE] [OPTIONS...]
 
 =head1 DESCRIPTION
 
-The C<bifhub new provider> command creates a new provider of bif hub
+The B<bif-new-provider> command creates a new provider of bif hub
 hosting.
 
 =head1 ARGUMENTS & OPTIONS
@@ -155,7 +159,7 @@ The creation message, set to "Created" by default.
 
 =head1 SEE ALSO
 
-L<bifhub>(1)
+L<bif>(1)
 
 =head1 AUTHOR
 
