@@ -1,17 +1,19 @@
 package App::bif::update;
 use strict;
 use warnings;
-use parent 'App::bif::Context';
+use Bif::Mo;
 
-our $VERSION = '0.1.0_28';
+our $VERSION = '0.1.2';
+extends 'App::bif';
 
 sub run {
-    my $self  = __PACKAGE__->new(shift);
-    my $info  = $self->get_topic( $self->uuid2id( $self->{id} ) );
+    my $self  = shift;
+    my $opts  = $self->opts;
+    my $info  = $self->get_topic( $self->uuid2id( $opts->{id} ) );
     my $class = "App::bif::update::$info->{kind}";
 
     if ( eval "require $class" ) {
-        $self->{path} = delete $self->{id}
+        $opts->{path} = delete $opts->{id}
           if ( $info->{kind} eq 'project' );
 
         return $class->can('run')->($self);
@@ -28,11 +30,13 @@ __END__
 
 =head1 NAME
 
+=for bif-doc #modify
+
 bif-update - change or comment a topic
 
 =head1 VERSION
 
-0.1.0_28 (2014-09-23)
+0.1.2 (2014-10-08)
 
 =head1 SYNOPSIS
 
