@@ -1,5 +1,5 @@
-CREATE TABLE func_import_update_delta(
-    update_uuid VARCHAR(40) NOT NULL,
+CREATE TABLE func_import_change_delta(
+    change_uuid VARCHAR(40) NOT NULL,
     action_format VARCHAR NOT NULL,
     action_topic_uuid_1 VARCHAR(40),
     action_topic_uuid_2 VARCHAR(40)
@@ -7,28 +7,28 @@ CREATE TABLE func_import_update_delta(
 
 
 CREATE TRIGGER
-    func_import_update_delta_bi_1
+    func_import_change_delta_bi_1
 BEFORE INSERT ON
-    func_import_update_delta
+    func_import_change_delta
 FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        NEW.update_uuid,
+        NEW.change_uuid,
         NEW.action_topic_uuid_1,
         NEW.action_topic_uuid_2
     );
 
     INSERT INTO
-        update_deltas(
-            update_id,
+        change_deltas(
+            change_id,
             new,
             action_format,
             action_topic_id_1,
             action_topic_id_2
         )
     SELECT
-        currval('updates'),
+        currval('changes'),
         1,
         NEW.action_format,
         t1.id,
