@@ -1,5 +1,5 @@
 CREATE TABLE func_new_hub_repo(
-    update_id INTEGER NOT NULL,
+    change_id INTEGER NOT NULL,
     id INTEGER NOT NULL DEFAULT (nextval('topics')),
     hub_id INTEGER NOT NULL,
     location VARCHAR NOT NULL
@@ -15,7 +15,7 @@ BEGIN
     SELECT debug(
         'TRIGGER func_new_hub_repo_bi_1',
         NEW.id,
-        NEW.update_id,
+        NEW.change_id,
         NEW.hub_id,
         NEW.location
     );
@@ -35,14 +35,14 @@ BEGIN
 
     INSERT INTO
         hub_repo_deltas(
-            update_id,
+            change_id,
             hub_id,
             hub_repo_id,
             new,
             location
         )
     VALUES(
-        NEW.update_id,
+        NEW.change_id,
         NEW.hub_id,
         NEW.id,
         1,
