@@ -1,5 +1,5 @@
 CREATE TABLE func_new_hub(
-    update_id INTEGER NOT NULL,
+    change_id INTEGER NOT NULL,
     id INTEGER NOT NULL DEFAULT (nextval('topics')),
     name VARCHAR(128),
     local INTEGER
@@ -15,7 +15,7 @@ BEGIN
     SELECT debug(
         'TRIGGER func_new_hub_bi_1',
         NEW.id,
-        NEW.update_id,
+        NEW.change_id,
         NEW.name,
         NEW.local
     );
@@ -34,13 +34,13 @@ BEGIN
 
     INSERT INTO
         hub_deltas(
-            update_id,
+            change_id,
             hub_id,
             name,
             new
         )
     VALUES(
-        NEW.update_id,
+        NEW.change_id,
         NEW.id,
         NEW.name,
         1
