@@ -1,5 +1,5 @@
 CREATE TABLE func_new_issue_status(
-    update_id INTEGER NOT NULL,
+    change_id INTEGER NOT NULL,
     id INTEGER NOT NULL DEFAULT (nextval('topics')),
     project_id INTEGER,
     status VARCHAR(40) NOT NULL,
@@ -41,7 +41,7 @@ BEGIN
 
     INSERT INTO
         issue_status_deltas(
-            update_id,
+            change_id,
             issue_status_id,
             new,
             status,
@@ -49,7 +49,7 @@ BEGIN
             def
         )
     VALUES(
-        NEW.update_id,
+        NEW.change_id,
         NEW.id,
         1,
         NEW.status,
